CrossmintAuthSession class final

Constructors

CrossmintAuthSession({required String jwt, String? refreshToken, String? userId, DateTime? expiresAt, DateTime? refreshTokenExpiresAt})
const

Properties

expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
jwt String
final
refreshToken String?
final
refreshTokenExpiresAt DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override